@@ -4,7 +4,7 @@ from opendelta.utils.signature import get_arg_names_inside_func, signature
 from typing import Optional, Union
 from transformers.models.distilbert.modeling_distilbert import MultiHeadSelfAttention
 from transformers.models.t5.modeling_t5 import T5Attention, T5LayerSelfAttention
-from transformers.models.bert.modeling_bert import BertSelfAttention
+from transformers.models.bert.modeling_bert import BertAttention
 from transformers.models.gpt2.modeling_gpt2 import GPT2Attention
 from transformers.models.bart.modeling_bart import BartAttention
 from transformers.models.roberta.modeling_roberta import RobertaAttention
@@ -12,7 +12,6 @@ from opendelta.utils.name_based_addressing import *
 from opendelta.utils.cuda import get_device
 from opendelta.basemodel import DeltaBase
 from transformers.models.t5 import T5ForConditionalGeneration
-import loralib as lora
 import torch.nn as nn
 import torch
 import opendelta.utils.logging as logging
@@ -29,15 +28,15 @@ class PrefixLayerT5(nn.Module):
         self.num_heads = num_heads
         self.device = device
         self.instantiated = False
-    
+
     def instantiate(self, hidden_dim):
         self.past_key = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_value = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_key_reparam = None
         self.past_value_reparam = None
         self.instantiated = True
-        
-    
+
+
     def pre_forward(self, *args, **kwargs):
         r"""The args and kwargs are inherited from the T5Attention's forward function.
         """
@@ -47,11 +46,11 @@ class PrefixLayerT5(nn.Module):
             self.hidden_dim = args[0].shape[-1]
             self.instantiate(hidden_dim=self.hidden_dim)
         if self.past_key_reparam is None:
-            past_key = self.past_key.data
+            past_key = self.past_key
         else:
             past_key = self.past_key_reparam
         if self.past_value_reparam is None:
-            past_value = self.past_value.data
+            past_value = self.past_value
         else:
             past_value = self.past_value_reparam
 
@@ -60,25 +59,25 @@ class PrefixLayerT5(nn.Module):
             x = x.reshape(self.prefix_token_num, self.num_heads, -1).transpose(0,1)
             x = x.unsqueeze(0).expand(batch_size, *x.shape)
             return x
-        
+
         if 'position_bias' in kwargs and kwargs['position_bias'] is not None:
-            if kwargs['position_bias'].shape[-1] != seq_len + self.prefix_token_num: # Then the position_bias should be re-calculated 
+            if kwargs['position_bias'].shape[-1] != seq_len + self.prefix_token_num: # Then the position_bias should be re-calculated
                 kwargs['position_bias'] = None
         if kwargs['past_key_value'] is None:
             kwargs['past_key_value'] = (expand_batchsize(past_key), expand_batchsize(past_value))
-        
+
         past_key_len = kwargs['past_key_value'][0].shape[-2]
-        
+
         if 'mask' in kwargs and kwargs['mask'] is not None:
             mask_len = kwargs['mask'].shape[-1]
             if past_key_len + seq_len == mask_len + self.prefix_token_num:
-       
+
                 am = kwargs['mask']  # Should check the format of the attention_mask when moving to a new plm.
                 kwargs['mask'] = torch.cat([-torch.zeros((*am.shape[:-1],self.prefix_token_num), dtype = am.dtype,device=am.device), am], dim=-1)
         return args, kwargs
-    
+
     def post_forward(self, output):
-        r""" Remove the cached positional bias, since the next layer may not have prefix token. 
+        r""" Remove the cached positional bias, since the next layer may not have prefix token.
         """
         output = output[:2] + (None, )+ output[3:]
         return output
@@ -93,29 +92,29 @@ class PrefixLayerBart(nn.Module):
         self.num_heads = num_heads
         self.device = device
         self.instantiated = False
-    
+
     def instantiate(self, hidden_dim):
         self.past_key = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_value = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_key_reparam = None
         self.past_value_reparam = None
         self.instantiated = True
-        
-    
+
+
     def pre_forward(self, *args, **kwargs):
         r"""The args and kwargs are inherited from the T5Attention's forward function.
         """
-      
+
         batch_size = kwargs['hidden_states'].shape[0]
         if not self.instantiated:
             self.hidden_dim = kwargs['hidden_states'].shape[-1]
             self.instantiate(hidden_dim=self.hidden_dim)
         if self.past_key_reparam is None:
-            past_key = self.past_key.data
+            past_key = self.past_key
         else:
             past_key = self.past_key_reparam
         if self.past_value_reparam is None:
-            past_value = self.past_value.data
+            past_value = self.past_value
         else:
             past_value = self.past_value_reparam
 
@@ -126,16 +125,16 @@ class PrefixLayerBart(nn.Module):
             x = x.unsqueeze(0).expand(batch_size, *x.shape)
             return x
         # from IPython import embe
-    
+
         if 'past_key_value' not in kwargs or kwargs['past_key_value'] is None:
             kwargs['past_key_value'] = (expand_batchsize(past_key), expand_batchsize(past_value))
-        
+
         if 'attention_mask' in kwargs and kwargs['attention_mask'] is not None:
             am = kwargs['attention_mask']  # Should check the format of the attention_mask when moving to a new plm.
             kwargs['attention_mask'] = torch.cat([-torch.zeros((*am.shape[:-1],self.prefix_token_num), dtype = am.dtype,device=am.device), am], dim=-1)
         return args, kwargs
-    
-    
+
+
 class PrefixLayerGPT2(nn.Module):
     r"""A layer of prefix tuning module. The layer's forward function pass (or concatenate) the additional past_key_value
     into the original attention layer's forward function.
@@ -146,15 +145,15 @@ class PrefixLayerGPT2(nn.Module):
         self.num_heads = num_heads
         self.device = device
         self.instantiated = False
-    
+
     def instantiate(self, hidden_dim):
         self.past_key = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_value = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_key_reparam = None
         self.past_value_reparam = None
         self.instantiated = True
-        
-    
+
+
     def pre_forward(self, *args, **kwargs):
         r"""The args and kwargs are inherited from the T5Attention's forward function.
         """
@@ -163,11 +162,11 @@ class PrefixLayerGPT2(nn.Module):
             self.hidden_dim = args[0].shape[-1]
             self.instantiate(hidden_dim=self.hidden_dim)
         if self.past_key_reparam is None:
-            past_key = self.past_key.data
+            past_key = self.past_key
         else:
             past_key = self.past_key_reparam
         if self.past_value_reparam is None:
-            past_value = self.past_value.data
+            past_value = self.past_value
         else:
             past_value = self.past_value_reparam
 
@@ -176,14 +175,14 @@ class PrefixLayerGPT2(nn.Module):
             x = x.unsqueeze(0).expand(batch_size, *x.shape)
             return x
 
-    
+
         if kwargs['layer_past'] is None:
             kwargs['layer_past'] = (expand_batchsize(past_key), expand_batchsize(past_value))
         if 'attention_mask' in kwargs and kwargs['attention_mask'] is not None:
             am = kwargs['attention_mask']  # Should check the format of the attention_mask when moving to a new plm.
             kwargs['attention_mask'] = torch.cat([-torch.zeros((*am.shape[:-1],self.prefix_token_num), dtype = am.dtype,device=am.device), am], dim=-1)
         return args, kwargs
-    
+
 
 
 class PrefixLayerDistilBert(nn.Module):
@@ -194,7 +193,7 @@ class PrefixLayerDistilBert(nn.Module):
         self.device = device
         self.key_instantiated = False
         self.value_instantiated = False
-    
+
     def forward(self, *args, **kwargs):
         mask = kwargs["mask"]
         key, value = kwargs['key'], kwargs['value']
@@ -207,24 +206,24 @@ class PrefixLayerDistilBert(nn.Module):
         kwargs['key'] = concated_key
         kwargs['value'] = concated_value
         return args, kwargs
-    
-    
+
+
     def key_instantiate(self, hidden_dim):
         self.past_key = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_key_reparam = None
         self.key_instantiated = True
-    
+
     def value_instantiate(self, hidden_dim):
         self.past_value = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_value_reparam = None
         self.value_instantiated = True
-        
+
     def key_pre_forward(self, *args, **kwargs):
         _input = args[0]
         _input = _input[:,self.prefix_token_num:, :]
         args = (_input,) +args[1:]
         return args, kwargs
-    
+
     def value_pre_forward(self, *args, **kwargs):
         _input = args[0]
         _input = _input[:,self.prefix_token_num:, :]
@@ -242,12 +241,12 @@ class PrefixLayerDistilBert(nn.Module):
             self.key_instantiate(hidden_dim=self.hidden_dim)
         batch_size = hiddens.shape[0]
         if self.past_key_reparam is None:
-            past_key = self.past_key.data
+            past_key = self.past_key
         else:
             past_key = self.past_key_reparam
         output = torch.cat([past_key.unsqueeze(0).expand(batch_size, *past_key.shape), hiddens], dim=1)
         return output
-    
+
     def value_forward(self, output: torch.Tensor):  ### Check whether run prefix is ok, 12.21
         if isinstance(output, torch.Tensor):
             hiddens = output
@@ -259,14 +258,14 @@ class PrefixLayerDistilBert(nn.Module):
             self.value_instantiate(hidden_dim=self.hidden_dim)
         batch_size = hiddens.shape[0]
         if self.past_value_reparam is None:
-            past_value = self.past_value.data
+            past_value = self.past_value
         else:
             past_value = self.past_value_reparam
         output = torch.cat([past_value.unsqueeze(0).expand(batch_size, *past_value.shape), hiddens], dim=1)
         return output
-    
 
-class PrefixLayerRoberta(nn.Module):
+
+class PrefixLayerBert(nn.Module):
     r"""A layer of prefix tuning module. The layer's forward function pass (or concatenate) the additional past_key_value
     into the original attention layer's forward function.
     """
@@ -276,15 +275,15 @@ class PrefixLayerRoberta(nn.Module):
         self.num_heads = num_heads
         self.device = device
         self.instantiated = False
-    
+
     def instantiate(self, hidden_dim):
         self.past_key = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_value = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
         self.past_key_reparam = None
         self.past_value_reparam = None
         self.instantiated = True
-        
-    
+
+
     def pre_forward(self, *args, **kwargs):
         r"""The args and kwargs are inherited from the T5Attention's forward function.
         """
@@ -293,25 +292,24 @@ class PrefixLayerRoberta(nn.Module):
             self.hidden_dim = args[0].shape[-1]
             self.instantiate(hidden_dim=self.hidden_dim)
         if self.past_key_reparam is None:
-            past_key = self.past_key.data
+            past_key = self.past_key
         else:
             past_key = self.past_key_reparam
         if self.past_value_reparam is None:
-            past_value = self.past_value.data
+            past_value = self.past_value
         else:
             past_value = self.past_value_reparam
 
-        # from IPython import embed
-        # embed()
+
         def expand_batchsize(x):
             x = x.reshape(self.prefix_token_num, self.num_heads, -1).transpose(0,1)
             x = x.unsqueeze(0).expand(batch_size, *x.shape)
             return x
         # from IPython import embe
-    
+
         if 'past_key_value' not in kwargs or kwargs['past_key_value'] is None:
             kwargs['past_key_value'] = (expand_batchsize(past_key), expand_batchsize(past_value))
-        
+
         if 'attention_mask' in kwargs and kwargs['attention_mask'] is not None:
             am = kwargs['attention_mask']  # Should check the format of the attention_mask when moving to a new plm.
             kwargs['attention_mask'] = torch.cat([-torch.zeros((*am.shape[:-1],self.prefix_token_num), dtype = am.dtype,device=am.device), am], dim=-1)
@@ -324,18 +322,77 @@ class PrefixLayerRoberta(nn.Module):
         return args, kwargs
 
 
-    
+
+class PrefixLayerRoberta(nn.Module):
+    r"""A layer of prefix tuning module. The layer's forward function pass (or concatenate) the additional past_key_value
+    into the original attention layer's forward function.
+    """
+    def __init__(self, prefix_token_num, num_heads, device,):
+        super().__init__()
+        self.prefix_token_num = prefix_token_num
+        self.num_heads = num_heads
+        self.device = device
+        self.instantiated = False
+
+    def instantiate(self, hidden_dim):
+        self.past_key = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
+        self.past_value = nn.Parameter(torch.randn(self.prefix_token_num, hidden_dim, device=self.device), requires_grad=True)
+        self.past_key_reparam = None
+        self.past_value_reparam = None
+        self.instantiated = True
+
+
+    def pre_forward(self, *args, **kwargs):
+        r"""The args and kwargs are inherited from the T5Attention's forward function.
+        """
+        batch_size = args[0].shape[0]
+        if not self.instantiated:
+            self.hidden_dim = args[0].shape[-1]
+            self.instantiate(hidden_dim=self.hidden_dim)
+        if self.past_key_reparam is None:
+            past_key = self.past_key
+        else:
+            past_key = self.past_key_reparam
+        if self.past_value_reparam is None:
+            past_value = self.past_value
+        else:
+            past_value = self.past_value_reparam
+
+        # from IPython import embed
+        # embed()
+        def expand_batchsize(x):
+            x = x.reshape(self.prefix_token_num, self.num_heads, -1).transpose(0,1)
+            x = x.unsqueeze(0).expand(batch_size, *x.shape)
+            return x
+        # from IPython import embe
+
+        if 'past_key_value' not in kwargs or kwargs['past_key_value'] is None:
+            kwargs['past_key_value'] = (expand_batchsize(past_key), expand_batchsize(past_value))
+
+        if 'attention_mask' in kwargs and kwargs['attention_mask'] is not None:
+            am = kwargs['attention_mask']  # Should check the format of the attention_mask when moving to a new plm.
+            kwargs['attention_mask'] = torch.cat([-torch.zeros((*am.shape[:-1],self.prefix_token_num), dtype = am.dtype,device=am.device), am], dim=-1)
+        elif len(args) >1: # attention mask is passed via positional argument
+            am = args[1]
+            am = torch.cat([-torch.zeros((*am.shape[:-1],self.prefix_token_num), dtype = am.dtype,device=am.device), am], dim=-1)
+            args = (args[0], am) + args[2:]
+        # from IPython import embed
+        # embed(header = "Herein prefixroberta")
+        return args, kwargs
+
+
+
     # def post_forward(self, output):
-    #     r""" Remove the cached positional bias, since the next layer may not have prefix token. 
+    #     r""" Remove the cached positional bias, since the next layer may not have prefix token.
     #     """
     #     output = output[:2] + (None, )+ output[3:]
     #     return output
-    
+
 
 class ReparameterizeFunction(nn.Module):
     r""" Prefix Tuning's performance is better with a reparameterize module, which generates
     the ``past_key_value`` using an MLP instead of directly optimizing the ``past_key_value`` as leaf variable.
-    In our implementation, the reparameterize module is constructed according to the number of parameters 
+    In our implementation, the reparameterize module is constructed according to the number of parameters
     in all ``past_key_value``s. Thus, variable number of prefixlayer is supported (not restricting to being equal
     to the number of layers of the pretraind language model)
 
@@ -351,10 +408,10 @@ class ReparameterizeFunction(nn.Module):
         self.record_parameters()
         self.compatibility_check()
         self.define_reparameterization_network()
-        
+
     def record_parameters(self):
         r""" Enumerate the parameters that need to be reparameterized.
-        Then, delete the original parameters. 
+        Then, delete the original parameters.
         """
         tot = 0
         for module in self.module_list:
@@ -362,14 +419,14 @@ class ReparameterizeFunction(nn.Module):
                 tot += parameters.numel()
                 module.register_parameter(n, None)
         self.total_parameters_num = tot
-    
+
     def compatibility_check(self,):
         r"""May be removed.
         """
         assert self.total_parameters_num % self.prefix_token_num == 0
-    
+
     def allocate_parameter(self):
-        r""" At the beginning of each forward pass through the whole network(PLM), 
+        r""" At the beginning of each forward pass through the whole network(PLM),
         cacalulate the reparameterized past_key and past_value (``past_key_reparam`` and ``past_value_reparam``)
         for later use in each layer.
         """
@@ -393,7 +450,7 @@ class ReparameterizeFunction(nn.Module):
         return args, kwargs
 
     def define_reparameterization_network(self) -> None:
-        r""" Build the reparameterize module 
+        r""" Build the reparameterize module
         """
         self.input_tokens = nn.Parameter(torch.arange(self.prefix_token_num).long(), requires_grad=False) # to allow automatic devicing
         self.wte = nn.Embedding(self.prefix_token_num, self.embed_dim)
@@ -406,20 +463,20 @@ class ReparameterizeFunction(nn.Module):
 
 class PrefixConfig(BaseDeltaConfig):
     def __init__(
-        self, 
+        self,
         prefix_token_num=6,
         reparameterize=True,
         embed_dim: Optional[int]=512,
         mid_dim: Optional[int]=512,
         **kwargs
-    ): 
+    ):
         super().__init__(**kwargs)
         arg_names = get_arg_names_inside_func(self.__init__)
         for arg_name in arg_names:
             if not hasattr(self, arg_name): # the arg has not been registered in parent config
                 setattr(self, arg_name, locals()[arg_name])
 
-    
+
 
 
 
@@ -427,24 +484,24 @@ class PrefixModel(DeltaBase):
     r""" The implementation of `Prefix-Tuning: Optimizing Continuous Prompts for Generation <https://arxiv.org/abs/2101.00190>`_ .
     However, as attention block of different PLM differs substantially, e.g., the input arguments, the name convention
     of ``past_key_value``, we have to implement different prefixlayer for different PLM. Given the inconvenience in the
-    code level, we only support several commonly used backbone models (Currently: T5, DistilBert,Bert, Roberta, GPT2, 
-    BART). If you are trying to apply delta tuning to other backbone models, we suggest you trying other delta models 
-    or implementing it and making a pull request. 
+    code level, we only support several commonly used backbone models (Currently: T5, DistilBert,Bert, Roberta, GPT2,
+    BART). If you are trying to apply delta tuning to other backbone models, we suggest you trying other delta models
+    or implementing it and making a pull request.
+
+    Experimental Feature:
+
+        Support inserting prefix token before each layer. For example, layer 3 4 6 10 and other layer untouched.
 
-    Experimental Feature: 
-        
-        Support inserting prefix token before each layer. For example, layer 3 4 6 10 and other layer untouched. 
-    
     .. note::
-    
+
         If using reparameterize, the parameters will be in a reparameterization network, not in the prefix, which
-        we attach to the first prefix layer. We will add a function to save only the generated prefix parameters for 
+        we attach to the first prefix layer. We will add a function to save only the generated prefix parameters for
         saving in the next version.
 
 
 
     Args:
-        backbone_model (:obj:`transformers.PretrainedModels`): The backbone model to be modified. 
+        backbone_model (:obj:`transformers.PretrainedModels`): The backbone model to be modified.
         prefix_token_num (:obj:`int`): the number of prefix token
         reparameterize (:obj:`bool`): Whether use the reparameterization for prefix tuning.
         embed_dim (:obj:`int`): The embeding dimension of prefix token when using the reparameterization.
@@ -453,26 +510,28 @@ class PrefixModel(DeltaBase):
                         the implemented ones)
         unfrozen_modules (:obj:`List[str]`, *optional*, default to :obj:`None`): The modules that should be unfrozen
                          together with the prefix parameters.
-        common_structure (:obj:`bool`): whether using name-based addressing witha common structure mapping.
+        common_structure (:obj:`bool`): whether using name-based addressing with a common structure mapping.
 
     """
     config_class = PrefixConfig
     delta_type = "prefix"
     default_modified_modules = ['attn']
     def __init__(self,
-                 backbone_model: nn.Module, 
+                 backbone_model: nn.Module,
                  prefix_token_num=6,
                  reparameterize=True,
                  embed_dim: Optional[int]=512,
                  mid_dim: Optional[int]=512,
                  modified_modules: Optional[List[str]] = None,
+                 exclude_modules: Optional[List[str]] = None,
                  unfrozen_modules: Optional[List[str]] = None,
                  common_structure: Optional[bool] = None,
                  interactive_modify: Optional[Union[bool, int]] = False,
                  ):
-        DeltaBase.__init__(self, 
-                           backbone_model, 
+        DeltaBase.__init__(self,
+                           backbone_model,
                            modified_modules=modified_modules,
+                           exclude_modules=exclude_modules,
                            unfrozen_modules=unfrozen_modules,
                            common_structure=common_structure,
                            interactive_modify=interactive_modify,
@@ -488,47 +547,47 @@ class PrefixModel(DeltaBase):
                                    self.modified_modules,
                                    )
 
-    def add_all_delta_to_backbone(self, 
-                 module: nn.Module, 
+    def add_all_delta_to_backbone(self,
+                 module: nn.Module,
                  modified_modules: List[str],
                 ) -> nn.Module:
-        first_modified_module = None 
-        # Current, We assume the layerer are in order in named_modules. 
+        first_modified_module = None
+        # Current, We assume the layerer are in order in named_modules.
         # Thus the first modified module is the first module that the tensor flows to.
-        for key, _ in module.named_modules(): 
+        for key, _ in module.named_modules():
             if self.find_key(key, modified_modules):
                 logger.debug("find key {}".format(key))
                 if first_modified_module is None:
                     _, _, ref = self.find_module(module, key)
                     first_modified_module = ref
                 self.update_module(module, key)
-        
+
         self._pseudo_data_to_instantiate(module)
-        
+
         if self.reparameterize:
-            reparams = ReparameterizeFunction(prefix_token_num=self.prefix_token_num, 
-                                              embed_dim=self.embed_dim, 
-                                              mid_dim=self.mid_dim, 
+            reparams = ReparameterizeFunction(prefix_token_num=self.prefix_token_num,
+                                              embed_dim=self.embed_dim,
+                                              mid_dim=self.mid_dim,
                                               module_list=self.delta_modules)
             self.delta_modules = None
             self.reparams = reparams
-            self.insert_sequential_module(first_modified_module, delta_module=reparams, name="reparams", strict=False)
+            self.insert_sequential_module(first_modified_module, delta_module=reparams, delta_name="reparams", strict=False)
         self.mark_as_delta()
         return module
-    
 
-    
+
+
     def update_module(self, module: nn.Module, key: str):
         _, _, ref = self.find_module(module, key)
 
         prefixlayer, ref = self.new_module_like(ref)
-        self.insert_sequential_module(ref, delta_module=prefixlayer, name="prefix")
-        self.delta_modules.append(prefixlayer)  
-    
+        self.insert_sequential_module(ref, delta_module=prefixlayer, delta_name="prefix")
+        self.delta_modules.append(prefixlayer)
+
     def new_module_like(self, module):
         # TODO: support more Attention modules
 
-        if isinstance(module, T5Attention) or isinstance(module, T5LayerSelfAttention): 
+        if isinstance(module, T5Attention) or isinstance(module, T5LayerSelfAttention):
             if isinstance(module, T5LayerSelfAttention):
                 module = module.SelfAttention # innermodule
             module_device = get_device(module)
@@ -538,8 +597,9 @@ class PrefixModel(DeltaBase):
             prefixlayer = PrefixLayerDistilBert(prefix_token_num=self.prefix_token_num, device=module_device)
             self.insert_sequential_module(getattr(module, "k_lin"), pre_caller=prefixlayer.key_pre_forward, post_caller=prefixlayer.key_forward)
             self.insert_sequential_module(getattr(module, "v_lin"), pre_caller=prefixlayer.value_pre_forward, post_caller=prefixlayer.value_forward)
-        elif isinstance(module, BertSelfAttention):
-            raise NotImplementedError
+        elif isinstance(module, BertAttention):
+            module_device = get_device(module)
+            prefixlayer = PrefixLayerBert(prefix_token_num=self.prefix_token_num, num_heads=module.self.num_attention_heads ,device=module_device)
         elif isinstance(module, RobertaAttention):
             module_device = get_device(module)
             prefixlayer = PrefixLayerRoberta(prefix_token_num=self.prefix_token_num, num_heads=module.self.num_attention_heads,device=module_device)
@@ -553,15 +613,14 @@ class PrefixModel(DeltaBase):
             raise NotImplementedError(type(module))
         return prefixlayer, module
 
-            
- 
-
-    
-   
 
 
 
-        
 
-        
-    
\ No newline at end of file
+
+
+
+
+
+
+
